@@ -160,7 +160,7 @@ public:
      * Will also destroy the toolbars, and menubar if
      * needed.
      */
-    virtual ~KMainWindow();
+    ~KMainWindow() override;
 
     /**
      * Retrieve the standard help menu.
@@ -381,7 +381,7 @@ public:
      * @param config Config group to read the settings from.
      *
      * KF5 porting note: the unused bool argument was removed, make sure to remove it from your
-     * reimplementations too! And add a Q_DECL_OVERRIDE for good measure.
+     * reimplementations too! And add a override for good measure.
      */
     virtual void applyMainWindowSettings(const KConfigGroup &config);
 
@@ -454,7 +454,7 @@ public Q_SLOTS:
      * \endcode
      *
      */
-    void appHelpActivated(void);
+    void appHelpActivated();
 
     /**
      * Tell the main window that it should save its settings when being closed.
@@ -471,7 +471,7 @@ protected:
      * if needed, once all constructor code for the main window has run.
      * Also reimplemented to catch when a QDockWidget is added or removed.
      */
-    bool event(QEvent *event) Q_DECL_OVERRIDE;
+    bool event(QEvent *event) override;
 
     /**
      * Reimplemented to autosave settings and call queryClose().
@@ -480,7 +480,7 @@ protected:
      * If you do it anyway, ensure to call the base implementation to keep
      * the feature of auto-saving window settings working.
      */
-    void closeEvent(QCloseEvent *) Q_DECL_OVERRIDE;
+    void closeEvent(QCloseEvent *) override;
 
     /**
        Called before the window is closed, either by the user or indirectly by
@@ -719,56 +719,21 @@ inline void kRestoreMainWindows()
             (new T)->restore(n);
         }
     }
-}
+} 
 
 /**
  * Restores the last session.
- * Overloaded method for usage with two different toplevel widget classes.
+ * Overloaded method for usage with multiple different toplevel widget classes.
  *
  * @tparam T0 one toplevel widget class
- * @tparam T1 other toplevel widget class
+ * @tparam T1 explicit other toplevel widget class for disambiguation from base template
+ * @tparam Tn Parameter pack to take 0..n further KMainWindows
  */
-template <typename T0, typename T1>
+template <typename T0, typename T1, typename ...Tn>
 inline void kRestoreMainWindows()
 {
-    const char *classNames[2];
-    classNames[0] = T0::staticMetaObject.className();
-    classNames[1] = T1::staticMetaObject.className();
-    for (int n = 1; KMainWindow::canBeRestored(n); ++n) {
-        const QString className = KMainWindow::classNameOfToplevel(n);
-        if (className == QLatin1String(classNames[0])) {
-            (new T0)->restore(n);
-        } else if (className == QLatin1String(classNames[1])) {
-            (new T1)->restore(n);
-        }
-    }
-}
-
-/**
- * Restores the last session.
- * Overloaded method for usage with three different toplevel widget classes.
- *
- * @tparam T0 one toplevel widget class
- * @tparam T1 other toplevel widget class
- * @tparam T2 yet another toplevel widget class
- */
-template <typename T0, typename T1, typename T2>
-inline void kRestoreMainWindows()
-{
-    const char *classNames[3];
-    classNames[0] = T0::staticMetaObject.className();
-    classNames[1] = T1::staticMetaObject.className();
-    classNames[2] = T2::staticMetaObject.className();
-    for (int n = 1; KMainWindow::canBeRestored(n); ++n) {
-        const QString className = KMainWindow::classNameOfToplevel(n);
-        if (className == QLatin1String(classNames[0])) {
-            (new T0)->restore(n);
-        } else if (className == QLatin1String(classNames[1])) {
-            (new T1)->restore(n);
-        } else if (className == QLatin1String(classNames[2])) {
-            (new T2)->restore(n);
-        }
-    }
+    kRestoreMainWindows<T0>();
+    kRestoreMainWindows<T1, Tn...>();
 }
 /** @}  */
 
